--- /dev/null
+++ chrome/renderer/renderer_main_platform_delegate_freebsd.cc
@@ -0,0 +1,51 @@
+// Copyright (c) 2009 The Chromium Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style license that can be
+// found in the LICENSE file.
+
+#include "chrome/renderer/renderer_main_platform_delegate.h"
+
+#include "base/command_line.h"
+#include "base/debug_util.h"
+#include "sandbox/linux/seccomp/sandbox.h"
+
+#include "chrome/common/chrome_switches.h"
+
+RendererMainPlatformDelegate::RendererMainPlatformDelegate(
+    const MainFunctionParams& parameters)
+        : parameters_(parameters) {
+}
+
+RendererMainPlatformDelegate::~RendererMainPlatformDelegate() {
+}
+
+void RendererMainPlatformDelegate::PlatformInitialize() {
+}
+
+void RendererMainPlatformDelegate::PlatformUninitialize() {
+}
+
+bool RendererMainPlatformDelegate::InitSandboxTests(bool no_sandbox) {
+  // The sandbox is started in the zygote process: zygote_main_linux.cc
+  // http://code.google.com/p/chromium/wiki/LinuxSUIDSandbox
+  return true;
+}
+
+bool RendererMainPlatformDelegate::EnableSandbox() {
+  // The setuid sandbox is started in the zygote process: zygote_main_linux.cc
+  // http://code.google.com/p/chromium/wiki/LinuxSUIDSandbox
+  //
+  // The seccomp sandbox is started in the renderer.
+  // http://code.google.com/p/seccompsandbox/
+#if defined(OS_LINUX) && defined(ARCH_CPU_X86_FAMILY) && !defined(CHROMIUM_SELINUX)
+  if (CommandLine::ForCurrentProcess()->HasSwitch(
+          switches::kEnableSeccompSandbox)) {
+    StartSeccompSandbox();
+  }
+#endif
+  return true;
+}
+
+void RendererMainPlatformDelegate::RunSandboxTests() {
+  // The sandbox is started in the zygote process: zygote_main_linux.cc
+  // http://code.google.com/p/chromium/wiki/LinuxSUIDSandbox
+}
diff --git chrome/renderer/renderer_webkitclient_impl.cc chrome/renderer/renderer_webkitclient_impl.cc
index 290c011..8d8fda7 100644
